|
Boost-Commit : |
Subject: [Boost-commit] svn:boost r65322 - in sandbox/geometry: boost/geometry/algorithms boost/geometry/geometries boost/geometry/geometries/register libs/geometry/doc/qbk libs/geometry/doc/qbk/reference libs/geometry/test/algorithms other/programs/doxygen_xml2qbk
From: barend.gehrels_at_[hidden]
Date: 2010-09-06 12:26:10
Author: barendgehrels
Date: 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
New Revision: 65322
URL: http://svn.boost.org/trac/boost/changeset/65322
Log:
Doc update
Renamed snippet to example
Added additional distinguishing qbk option
Some doc fixes
Text files modified:
sandbox/geometry/boost/geometry/algorithms/area.hpp | 7 ++-
sandbox/geometry/boost/geometry/algorithms/centroid.hpp | 4 ++
sandbox/geometry/boost/geometry/algorithms/distance.hpp | 2 +
sandbox/geometry/boost/geometry/algorithms/intersection.hpp | 5 +-
sandbox/geometry/boost/geometry/algorithms/intersects.hpp | 14 ++++--
sandbox/geometry/boost/geometry/algorithms/length.hpp | 2 +
sandbox/geometry/boost/geometry/algorithms/num_points.hpp | 3 +
sandbox/geometry/boost/geometry/algorithms/perimeter.hpp | 2 +
sandbox/geometry/boost/geometry/algorithms/simplify.hpp | 9 +---
sandbox/geometry/boost/geometry/algorithms/within.hpp | 2 +
sandbox/geometry/boost/geometry/geometries/point.hpp | 2
sandbox/geometry/boost/geometry/geometries/register/point.hpp | 2
sandbox/geometry/libs/geometry/doc/qbk/geometry.qbk | 1
sandbox/geometry/libs/geometry/doc/qbk/reference.qbk | 6 +-
sandbox/geometry/libs/geometry/doc/qbk/reference/area.qbk | 19 +---------
sandbox/geometry/libs/geometry/doc/qbk/reference/buffer.qbk | 11 +----
sandbox/geometry/libs/geometry/doc/qbk/reference/centroid.qbk | 30 +---------------
sandbox/geometry/libs/geometry/doc/qbk/reference/convex_hull.qbk | 4 +-
sandbox/geometry/libs/geometry/doc/qbk/reference/distance.qbk | 2
sandbox/geometry/libs/geometry/doc/qbk/reference/envelope.qbk | 4 +-
sandbox/geometry/libs/geometry/doc/qbk/reference/intersection.qbk | 15 +------
sandbox/geometry/libs/geometry/doc/qbk/reference/intersects.qbk | 12 +++---
sandbox/geometry/libs/geometry/doc/qbk/reference/length.qbk | 15 --------
sandbox/geometry/libs/geometry/doc/qbk/reference/num_points.qbk | 3 +
sandbox/geometry/libs/geometry/doc/qbk/reference/perimeter.qbk | 14 -------
sandbox/geometry/libs/geometry/doc/qbk/reference/point.qbk | 2
sandbox/geometry/libs/geometry/doc/qbk/reference/register.qbk | 14 +++---
sandbox/geometry/libs/geometry/doc/qbk/reference/simplify.qbk | 16 +-------
sandbox/geometry/libs/geometry/doc/qbk/reference/within.qbk | 2
sandbox/geometry/libs/geometry/test/algorithms/disjoint.cpp | 13 +++++++
sandbox/geometry/other/programs/doxygen_xml2qbk/doxygen_xml2qbk.cpp | 73 ++++++++++++++++-----------------------
31 files changed, 117 insertions(+), 193 deletions(-)
Modified: sandbox/geometry/boost/geometry/algorithms/area.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/area.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/area.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -204,8 +204,8 @@
\param geometry \param_geometry
\return \return_calc{area}
-\qbk{snippet,area_polygon}
-\qbk{snippet,area_polygon_spherical}
+\qbk{example,area_polygon}
+\qbk{example,area_polygon_spherical}
\qbk{behavior,__0dim__:[qbk_ret 0]}
\qbk{behavior,__1dim__:[qbk_ret 0]}
\qbk{behavior,__2dim__:[qbk_ret the area]}
@@ -240,7 +240,8 @@
\param strategy \param_strategy{area}
\return \return_calc{area}
-\qbk{snippet,area_polygon_strategy}
+\qbk{distinguish,with strategy}
+\qbk{example,area_polygon_strategy}
*/
template <typename Geometry, typename Strategy>
inline typename Strategy::return_type area(
Modified: sandbox/geometry/boost/geometry/algorithms/centroid.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/centroid.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/centroid.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -362,6 +362,8 @@
\param geometry \param_geometry
\param c \param_point \param_set{centroid}
\param strategy \param_strategy{centroid}
+
+\qbk{distinguish,with strategy}
*/
template<typename Geometry, typename Point, typename Strategy>
inline void centroid(Geometry const& geometry, Point& c,
@@ -448,6 +450,8 @@
\param geometry \param_geometry
\param strategy \param_strategy{centroid}
\return \return_calc{centroid}
+
+\qbk{distinguish,with strategy}
*/
template<typename Point, typename Geometry, typename Strategy>
inline Point make_centroid(Geometry const& geometry, Strategy const& strategy)
Modified: sandbox/geometry/boost/geometry/algorithms/distance.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/distance.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/distance.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -480,6 +480,8 @@
\note The strategy can be a point-point strategy. In case of distance point-line/point-polygon
it may also be a point-segment strategy.
+\qbk{distinguish,with strategy}
+
\par Example:
Example showing distance calculation of two lat long points, using the accurate Vincenty approximation
\dontinclude doxygen_1.cpp
Modified: sandbox/geometry/boost/geometry/algorithms/intersection.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/intersection.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/intersection.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -261,6 +261,7 @@
\param strategy The strategy
\return \return_out
+\qbk{distinguish,with strategy}
\qbk{behavior,[qbk_out __point__]:Calculates intersection points of input geometries}
\qbk{behavior,[qbk_out __linestring__]:Calculates intersection linestrings of input geometries (NYI)}
\qbk{behavior,[qbk_out __polygon__]:Calculates intersection polygons input (multi)polygons and/or boxes}
@@ -321,7 +322,7 @@
\param out \param_out{intersection}
\return \return_out
-\qbk{snippet,intersection_segment_inserter}
+\qbk{example,intersection_segment_inserter}
*/
template
<
@@ -362,7 +363,7 @@
\param geometry2 \param_geometry
\param output_collection The collection being filled or extended by the algorithm
-\qbk{snippet,intersection_linestring}
+\qbk{example,intersection_linestring}
*/
template
<
Modified: sandbox/geometry/boost/geometry/algorithms/intersects.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/intersects.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/intersects.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -21,14 +21,16 @@
{
/*!
-\brief \brief_check{at least one intersection(crossing or self-tangency)}
+\brief \brief_check{has at least one intersection (crossing or self-tangency)}
\note This function can be called for one geometry (self-intersection) and
also for two geometries (intersection)
\ingroup intersects
-\tparam Geometry geometry type
-\param geometry geometry
+\tparam Geometry \tparam_geometry
+\param geometry \param_geometry
\return \return_check{is self-intersecting}
- */
+
+\qbk{distinguish,one geometry}
+*/
template <typename Geometry>
inline bool intersects(Geometry const& geometry)
{
@@ -51,7 +53,7 @@
typedef detail::overlay::get_turn_info
<
- typename point_type<Geometry>::type,
+ typename point_type<Geometry>::type,
typename point_type<Geometry>::type,
turn_info,
detail::overlay::assign_null_policy
@@ -77,6 +79,8 @@
\param geometry1 \param_geometry
\param geometry2 \param_geometry
\return \return_check2{intersect each other}
+
+\qbk{distinguish,two geometries}
*/
template <typename Geometry1, typename Geometry2>
inline bool intersects(Geometry1 const& geometry1, Geometry2 const& geometry2)
Modified: sandbox/geometry/boost/geometry/algorithms/length.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/length.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/length.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -184,6 +184,8 @@
\param strategy \param_strategy{distance}
\return \return_calc{length}
+\qbk{distinguish,with strategy}
+
\par Example:
Example showing length calculation using iterators
and the Vincenty strategy
Modified: sandbox/geometry/boost/geometry/algorithms/num_points.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/num_points.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/num_points.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -124,7 +124,8 @@
\return \return_calc{number of points}
\qbk{behavior,__point__:[qbk_ret 1]}
-\qbk{behavior,__box__:[qbk_ret 1]}
+\qbk{behavior,__segment__:[qbk_ret 2]}
+\qbk{behavior,__box__:[qbk_ret 4]}
\qbk{behavior,__range__:[qbk_ret boost::size(geometry)]}
\qbk{behavior,__other__:[qbk_ret the sum of the number of points of its elements]}
\qbk{complexity,Constant or Linear}
Modified: sandbox/geometry/boost/geometry/algorithms/perimeter.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/perimeter.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/perimeter.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -109,6 +109,8 @@
\param geometry \param_geometry
\param strategy strategy to be used for distance calculations.
\return \return_calc{perimeter}
+
+\qbk{distinguish,with strategy}
*/
template<typename Geometry, typename Strategy>
inline typename length_result<Geometry>::type perimeter(
Modified: sandbox/geometry/boost/geometry/algorithms/simplify.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/simplify.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/simplify.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -248,7 +248,7 @@
include point-distance strategy
\image html svg_simplify_country.png "The image below presents the simplified country"
-\qbk{complexity,Linear}
+\qbk{distinguish,with strategy}
*/
template<typename Geometry, typename Distance, typename Strategy>
inline void simplify(Geometry const& geometry, Geometry& out,
@@ -290,8 +290,6 @@
\line {
\until }
-
-\qbk{complexity,Linear}
*/
template<typename Geometry, typename Distance>
inline void simplify(Geometry const& geometry, Geometry& out,
@@ -332,8 +330,8 @@
\line {
\until }
-\qbk{snippet,simplify_inserter}
-\qbk{complexity,Linear}
+\qbk{distinguish,with strategy}
+\qbk{example,simplify_inserter}
*/
template<typename Geometry, typename OutputIterator, typename Distance, typename Strategy>
inline void simplify_inserter(Geometry const& geometry, OutputIterator out,
@@ -359,7 +357,6 @@
\param max_distance distance (in units of input coordinates) of a vertex
to other segments to be removed
-\qbk{complexity,Linear}
*/
template<typename Geometry, typename OutputIterator, typename Distance>
inline void simplify_inserter(Geometry const& geometry, OutputIterator out,
Modified: sandbox/geometry/boost/geometry/algorithms/within.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/algorithms/within.hpp (original)
+++ sandbox/geometry/boost/geometry/algorithms/within.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -366,6 +366,8 @@
\param strategy strategy to be used
\return true if geometry1 is completely contained within geometry2,
else false
+
+\qbk{distinguish,with strategy}
*/
template<typename Geometry1, typename Geometry2, typename Strategy>
inline bool within(Geometry1 const& geometry1, Geometry2 const& geometry2,
Modified: sandbox/geometry/boost/geometry/geometries/point.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/geometries/point.hpp (original)
+++ sandbox/geometry/boost/geometry/geometries/point.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -30,7 +30,7 @@
\tparam DimensionCount number of coordinates, usually 2 or 3
\tparam CoordinateSystem coordinate system, for example cs::cartesian
-\qbk{snippet,point}
+\qbk{example,point}
\details Defines a neutral point class, fulfilling the Point Concept.
Library users can use this point class, or use their own point classes.
Modified: sandbox/geometry/boost/geometry/geometries/register/point.hpp
==============================================================================
--- sandbox/geometry/boost/geometry/geometries/register/point.hpp (original)
+++ sandbox/geometry/boost/geometry/geometries/register/point.hpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -59,7 +59,7 @@
\param Field0 Member containing first (usually x) coordinate
\param Field1 Member containing second (usually y) coordinate
-\qbk{snippet, boost_geometry_register_point_2d}
+\qbk{example, boost_geometry_register_point_2d}
\qbk{admonition, [caution Use the macro outside any namespace]}
\qbk{admonition, [note A point can include a namespace]}
*/
Modified: sandbox/geometry/libs/geometry/doc/qbk/geometry.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/geometry.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/geometry.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -34,6 +34,7 @@
[def __rev__ Reversed polygon (coordinates not according their orientiation)]
[def __empty__ Empty (e.g. polygon without points)]
[def __box__ Rectangle]
+[def __segment__ Segment]
[def __point__ Point]
[def __linestring__ Linestring]
[def __polygon__ Polygon]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -56,9 +56,9 @@
[include reference/intersection.qbk]
[endsect]
-[/section:intersects intersects]
-[/include reference/intersects.qbk]
-[/endsect]
+[section:intersects intersects]
+[include reference/intersects.qbk]
+[endsect]
[section:length length]
[include reference/length.qbk]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/area.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/area.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/area.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -46,7 +46,7 @@
[heading Complexity]
Linear
-[heading Snippets]
+[heading Examples]
[area_polygon]
[area_polygon_spherical]
@@ -85,22 +85,7 @@
`#include <boost/geometry/algorithms/area.hpp>`
-[heading Behavior]
-[table
-[[Case] [Behavior] ]
-[[__0dim__][[qbk_ret 0]]]
-[[__1dim__][[qbk_ret 0]]]
-[[__2dim__][[qbk_ret the area]]]
-[[__cart__][[qbk_ret the area] __cs_units__]]
-[[__sph__][[qbk_ret the area] __sph1__]]
-[[__rev__][[qbk_ret the negative area]]]
-]
-
-
-[heading Complexity]
-Linear
-
-[heading Snippets]
+[heading Examples]
[area_polygon_strategy]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/buffer.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/buffer.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/buffer.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,6 +1,6 @@
[/ Generated by doxygen_xml2qbk, don't change, it will be overwritten automatically]
[/ Generated from ..\doxygen_output\xml\group__buffer.xml]
-[section:buffer_4 buffer]
+[section:buffer buffer]
Calculates the buffer of a geometry.
@@ -41,7 +41,7 @@
[endsect]
-[section:make_buffer_3 make_buffer]
+[section:make_buffer make_buffer]
Calculates the buffer of a geometry.
@@ -76,13 +76,6 @@
`#include <boost/geometry/algorithms/buffer.hpp>`
-[heading Behavior]
-[table
-[[Case] [Behavior] ]
-[[__box__/__box__][Returns a new rectangular box, enlarged with the specified distance. It is allowed that "geometry_out" the same object as "geometry_in"]]
-]
-
-
[endsect]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/centroid.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/centroid.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/centroid.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -17,7 +17,7 @@
[[Type] [Concept] [Name] [Description] ]
[[Geometry const &] [Any type fulfilling a Geometry Concept ] [geometry] [A model of the specified concept ]]
[[Point &] [Any type fulfilling a Point Concept ] [c] [A model of the specified Point Concept which is set to the centroid ]]
-[[Strategy const &] [Any type fulfilling a Centroid Strategy Concept ] [strategy] [The strategy which will be used for centroid calculations ]]
+[[Strategy const &] [Any type fulfilling a Centroid Strategy Concept ] [strategy] [The strategy which will be used for centroid calculations]]
]
@@ -123,19 +123,6 @@
`#include <boost/geometry/algorithms/centroid.hpp>`
-[heading Behavior]
-[table
-[[Case] [Behavior] ]
-[[__0dim__][Calculates centroid]]
-[[__1dim__][Calculates centroid]]
-[[__2dim__][Calculates centroid]]
-[[__empty__][Throws a centroid_exception]]
-]
-
-
-[heading Complexity]
-Linear
-
[endsect]
@@ -161,7 +148,7 @@
[heading Returns]
-The calculated centroid
+The calculated centroid
[heading Header]
Either
@@ -172,19 +159,6 @@
`#include <boost/geometry/algorithms/centroid.hpp>`
-[heading Behavior]
-[table
-[[Case] [Behavior] ]
-[[__0dim__][Calculates centroid]]
-[[__1dim__][Calculates centroid]]
-[[__2dim__][Calculates centroid]]
-[[__empty__][Throws a centroid_exception]]
-]
-
-
-[heading Complexity]
-Linear
-
[endsect]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/convex_hull.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/convex_hull.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/convex_hull.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,6 +1,6 @@
[/ Generated by doxygen_xml2qbk, don't change, it will be overwritten automatically]
[/ Generated from ..\doxygen_output\xml\group__convex__hull.xml]
-[section:convex_hull_2 convex_hull]
+[section:convex_hull convex_hull]
Calculates the convex hull of a geometry.
@@ -32,7 +32,7 @@
[endsect]
-[section:convex_hull_inserter_2 convex_hull_inserter]
+[section:convex_hull_inserter convex_hull_inserter]
Calculate the convex hull of a geometry, output-iterator version.
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/distance.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/distance.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/distance.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,6 +1,6 @@
[/ Generated by doxygen_xml2qbk, don't change, it will be overwritten automatically]
[/ Generated from ..\doxygen_output\xml\group__distance.xml]
-[section:comparable_distance_2 comparable_distance]
+[section:comparable_distance comparable_distance]
Calculate the comparable distance measurement of two geometries.
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/envelope.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/envelope.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/envelope.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,6 +1,6 @@
[/ Generated by doxygen_xml2qbk, don't change, it will be overwritten automatically]
[/ Generated from ..\doxygen_output\xml\group__envelope.xml]
-[section:envelope_2 envelope]
+[section:envelope envelope]
Calculates the envelope of a geometry.
@@ -32,7 +32,7 @@
[endsect]
-[section:make_envelope_1 make_envelope]
+[section:make_envelope make_envelope]
Calculates the envelope of a geometry.
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/intersection.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/intersection.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/intersection.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,6 +1,6 @@
[/ Generated by doxygen_xml2qbk, don't change, it will be overwritten automatically]
[/ Generated from ..\doxygen_output\xml\group__intersection.xml]
-[section:intersection_3 intersection]
+[section:intersection intersection]
Calculate the intersection of two geometries.
@@ -39,7 +39,7 @@
]
-[heading Snippets]
+[heading Examples]
[intersection_linestring]
@@ -126,16 +126,7 @@
`#include <boost/geometry/algorithms/intersection.hpp>`
-[heading Behavior]
-[table
-[[Case] [Behavior] ]
-[[[qbk_out __point__]][Calculates intersection points of input geometries]]
-[[[qbk_out __linestring__]][Calculates intersection linestrings of input geometries (NYI)]]
-[[[qbk_out __polygon__]][Calculates intersection polygons input (multi)polygons and/or boxes]]
-]
-
-
-[heading Snippets]
+[heading Examples]
[intersection_segment_inserter]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/intersects.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/intersects.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/intersects.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,8 +1,8 @@
[/ Generated by doxygen_xml2qbk, don't change, it will be overwritten automatically]
[/ Generated from ..\doxygen_output\xml\group__intersects.xml]
-[section:intersects_1 intersects]
+[section:intersects_1 intersects (one geometry)]
-Checks if a geometry at least one intersection(crossing or self-tangency).
+Checks if a geometry has at least one intersection (crossing or self-tangency).
[heading Synopsis]
``template<typename Geometry>
@@ -12,12 +12,12 @@
[table
[[Type] [Concept] [Name] [Description] ]
-[[Geometry const &] [geometry type ] [geometry] [geometry ]]
+[[Geometry const &] [Any type fulfilling a Geometry Concept ] [geometry] [A model of the specified concept ]]
]
[heading Returns]
-Returns true if the geometry is self-intersecting
+Returns true if the geometry is self-intersecting
[heading Header]
Either
@@ -31,7 +31,7 @@
[endsect]
-[section:intersects_2 intersects]
+[section:intersects_2 intersects (two geometries)]
Checks if two geometries have at least one intersection.
@@ -49,7 +49,7 @@
[heading Returns]
-Returns true if two geometries intersect each other
+Returns true if two geometries intersect each other
[heading Header]
Either
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/length.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/length.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/length.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -50,9 +50,6 @@
Calculates the length of a geometry using the specified strategy.
-[heading Description]
-The version with a specified strategy uses that strategy to calculate distances between consecutive points, summing them to the length of the geometry. Reasons to specify a strategy include: use another coordinate system for calculations; construct the strategy beforehand (e.g. with the radius of the Earth); select a strategy when there are more than one available for a calculation (e.g. distance over the Earth)
-
[heading Synopsis]
``template<typename Geometry, typename Strategy>
length_result<Geometry>::type length (Geometry const &geometry, Strategy const &strategy)``
@@ -78,18 +75,6 @@
`#include <boost/geometry/algorithms/length.hpp>`
-[heading Behavior]
-[table
-[[Case] [Behavior] ]
-[[__0dim__][[qbk_ret 0]]]
-[[__1dim__][[qbk_ret the length]]]
-[[__2dim__][[qbk_ret 0]]]
-]
-
-
-[heading Complexity]
-Linear
-
[endsect]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/num_points.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/num_points.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/num_points.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -35,7 +35,8 @@
[table
[[Case] [Behavior] ]
[[__point__][[qbk_ret 1]]]
-[[__box__][[qbk_ret 1]]]
+[[__segment__][[qbk_ret 2]]]
+[[__box__][[qbk_ret 4]]]
[[__range__][[qbk_ret boost::size(geometry)]]]
[[__other__][[qbk_ret the sum of the number of points of its elements]]]
]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/perimeter.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/perimeter.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/perimeter.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -67,7 +67,7 @@
[heading Returns]
-The calculated perimeter
+The calculated perimeter
[heading Header]
Either
@@ -78,18 +78,6 @@
`#include <boost/geometry/algorithms/perimeter.hpp>`
-[heading Behavior]
-[table
-[[Case] [Behavior] ]
-[[__0dim__][Returns zero]]
-[[__1dim__][Returns zero]]
-[[__2dim__][Returns the perimeter]]
-]
-
-
-[heading Complexity]
-Linear
-
[endsect]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/point.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/point.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/point.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -77,7 +77,7 @@
`#include <boost/geometry/geometries/point.hpp>`
-[heading Snippets]
+[heading Examples]
[point]
[endsect]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/register.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/register.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/register.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,6 +1,6 @@
[/ Generated by doxygen_xml2qbk, don't change, it will be overwritten automatically]
[/ Generated from ..\doxygen_output\xml\group__register.xml]
-[section:BOOST_GEOMETRY_REGISTER_POINT_2D_5 BOOST_GEOMETRY_REGISTER_POINT_2D]
+[section:BOOST_GEOMETRY_REGISTER_POINT_2D BOOST_GEOMETRY_REGISTER_POINT_2D]
Macro to register a custom 2D point.
@@ -30,13 +30,13 @@
[caution Use the macro outside any namespace]
[note A point can include a namespace]
-[heading Snippets]
+[heading Examples]
[boost_geometry_register_point_2d]
[endsect]
-[section:BOOST_GEOMETRY_REGISTER_POINT_2D_CONST_5 BOOST_GEOMETRY_REGISTER_POINT_2D_CONST]
+[section:BOOST_GEOMETRY_REGISTER_POINT_2D_CONST BOOST_GEOMETRY_REGISTER_POINT_2D_CONST]
Macro to register a custom 2D point (CONST version).
@@ -67,7 +67,7 @@
[endsect]
-[section:BOOST_GEOMETRY_REGISTER_POINT_2D_GET_SET_7 BOOST_GEOMETRY_REGISTER_POINT_2D_GET_SET]
+[section:BOOST_GEOMETRY_REGISTER_POINT_2D_GET_SET BOOST_GEOMETRY_REGISTER_POINT_2D_GET_SET]
Macro to register a custom 2D point (having separate get/set methods).
@@ -100,7 +100,7 @@
[endsect]
-[section:BOOST_GEOMETRY_REGISTER_POINT_3D_6 BOOST_GEOMETRY_REGISTER_POINT_3D]
+[section:BOOST_GEOMETRY_REGISTER_POINT_3D BOOST_GEOMETRY_REGISTER_POINT_3D]
Macro to register a custom 3D point.
@@ -132,7 +132,7 @@
[endsect]
-[section:BOOST_GEOMETRY_REGISTER_POINT_3D_CONST_6 BOOST_GEOMETRY_REGISTER_POINT_3D_CONST]
+[section:BOOST_GEOMETRY_REGISTER_POINT_3D_CONST BOOST_GEOMETRY_REGISTER_POINT_3D_CONST]
Macro to register a custom 3D point (CONST version).
@@ -164,7 +164,7 @@
[endsect]
-[section:BOOST_GEOMETRY_REGISTER_POINT_3D_GET_SET_9 BOOST_GEOMETRY_REGISTER_POINT_3D_GET_SET]
+[section:BOOST_GEOMETRY_REGISTER_POINT_3D_GET_SET BOOST_GEOMETRY_REGISTER_POINT_3D_GET_SET]
Macro to register a custom 3D point (having separate get/set methods).
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/simplify.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/simplify.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/simplify.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -28,9 +28,6 @@
`#include <boost/geometry/algorithms/simplify.hpp>`
-[heading Complexity]
-Linear
-
[heading Image(s)]
[$svg_simplify_country.png]
@@ -63,9 +60,6 @@
`#include <boost/geometry/algorithms/simplify.hpp>`
-[heading Complexity]
-Linear
-
[endsect]
@@ -97,10 +91,7 @@
`#include <boost/geometry/algorithms/simplify.hpp>`
-[heading Complexity]
-Linear
-
-[heading Snippets]
+[heading Examples]
[simplify_inserter]
@@ -120,7 +111,7 @@
[[Type] [Concept] [Name] [Description] ]
[[Geometry const &] [Any type fulfilling a Geometry Concept ] [geometry] [input geometry, to be simplified ]]
[[OutputIterator] [] [out] [output iterator, outputs all simplified points ]]
-[[Distance const &] [] [max_distance] [distance (in units of input coordinates) of a vertex to other segments to be removed]]
+[[Distance const &] [] [max_distance] [distance (in units of input coordinates) of a vertex to other segments to be removed ]]
]
@@ -133,9 +124,6 @@
`#include <boost/geometry/algorithms/simplify.hpp>`
-[heading Complexity]
-Linear
-
[endsect]
Modified: sandbox/geometry/libs/geometry/doc/qbk/reference/within.qbk
==============================================================================
--- sandbox/geometry/libs/geometry/doc/qbk/reference/within.qbk (original)
+++ sandbox/geometry/libs/geometry/doc/qbk/reference/within.qbk 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -51,7 +51,7 @@
[heading Returns]
-true if geometry1 is completely contained within geometry2, else false
+true if geometry1 is completely contained within geometry2, else false
[heading Header]
Either
Modified: sandbox/geometry/libs/geometry/test/algorithms/disjoint.cpp
==============================================================================
--- sandbox/geometry/libs/geometry/test/algorithms/disjoint.cpp (original)
+++ sandbox/geometry/libs/geometry/test/algorithms/disjoint.cpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -98,6 +98,19 @@
// Test if within(a,b) returns false for disjoint
test_disjoint<ring, ring>("within_simplex_rr1", within_simplex[0], within_simplex[1], false);
test_disjoint<ring, ring>("within_simplex_rr2", within_simplex[1], within_simplex[0], false);
+
+ // Linear
+ typedef boost::geometry::linestring<P> ls;
+ typedef boost::geometry::model::segment<P> segment;
+ test_disjoint<ls, ls>("ls/ls 1", "linestring(0 0,1 1)", "linestring(1 0,0 1)", false);
+ test_disjoint<ls, ls>("ls/ls 2", "linestring(0 0,1 1)", "linestring(1 0,2 1)", true);
+ test_disjoint<segment, segment>("s/s 1", "linestring(0 0,1 1)", "linestring(1 0,0 1)", false);
+ test_disjoint<segment, segment>("s/s 2", "linestring(0 0,1 1)", "linestring(1 0,2 1)", true);
+ // TODO test_disjoint<segment, ls>("s/ls 1", "linestring(0 0,1 1)", "linestring(1 0,0 1)", false);
+ // TODO test_disjoint<segment, ls>("s/ls 2", "linestring(0 0,1 1)", "linestring(1 0,2 1)", true);
+ // TODO test_disjoint<ls, segment>("ls/s 1", "linestring(0 0,1 1)", "linestring(1 0,0 1)", false);
+ // TODO test_disjoint<ls, segment>("ls/s 2", "linestring(0 0,1 1)", "linestring(1 0,2 1)", true);
+
}
int test_main(int, char* [])
Modified: sandbox/geometry/other/programs/doxygen_xml2qbk/doxygen_xml2qbk.cpp
==============================================================================
--- sandbox/geometry/other/programs/doxygen_xml2qbk/doxygen_xml2qbk.cpp (original)
+++ sandbox/geometry/other/programs/doxygen_xml2qbk/doxygen_xml2qbk.cpp 2010-09-06 12:26:04 EDT (Mon, 06 Sep 2010)
@@ -1,4 +1,4 @@
-// Boost.Geometry (aka GGL, Generic Geometry Library)
+// doxygen_xml2qbk (developed in the context of Boost.Geometry documentation)
//
// Copyright Barend Gehrels 2010, Geodan, Amsterdam, the Netherlands
// Use, modification and distribution is subject to the Boost Software License,
@@ -14,7 +14,7 @@
// - basically generic, but implemented with Boost.Geometry in mind
// - makes use of some specific XML elements, which can be created by Doxygen
// using /xmlonly
// currently this is the element <qbk.snippet> which will make a reference
// to an example.
// - earlier generations of QBK was done by XSLT, I'm not so into the XSLT and
// think this is more flexible. The XSLT only did point-structure, not yet
@@ -117,12 +117,16 @@
std::string brief_description, detailed_description;
std::string location;
int line; // To sort - Doxygen changes order - we change it back
- std::vector<std::string> snippets;
+ std::vector<std::string> examples;
std::vector<std::string> behaviors;
std::vector<std::string> admonitions;
std::vector<std::string> images;
std::string complexity;
+ // To distinguish overloads: unary, binary etc,
+ // Filled with: \qbk{distinguish,<A discerning description>}
+ std::string additional_description;
+
std::vector<param> template_parameters;
std::vector<param> parameters;
@@ -138,6 +142,7 @@
function_type type;
std::string definition, argsstring;
std::string return_type, return_description;
+
bool unique;
function()
@@ -332,9 +337,9 @@
el.location = loc;
el.line = atol(get_attribute(node, "line").c_str());
}
- else if (full == ".detaileddescription.para.qbk.snippet")
+ else if (full == ".detaileddescription.para.qbk.example")
{
- el.snippets.push_back(boost::trim_copy(std::string(node->value())));
+ el.examples.push_back(boost::trim_copy(std::string(node->value())));
}
else if (full == ".detaileddescription.para.qbk.admonition")
{
@@ -349,6 +354,11 @@
el.complexity = node->value();
boost::trim(el.complexity);
}
+ else if (full == ".detaileddescription.para.qbk.distinguish")
+ {
+ el.additional_description = node->value();
+ boost::trim(el.additional_description);
+ }
else if (full == ".templateparamlist")
{
parse_parameter_list(node->first_node(), el.template_parameters);
@@ -591,14 +601,14 @@
}
}
-void quickbook_snippets(std::vector<std::string> const& snippets, std::ostream& out)
+void quickbook_snippets(std::vector<std::string> const& examples, std::ostream& out)
{
- if (! snippets.empty())
+ if (! examples.empty())
{
- out << "[heading Snippets]" << std::endl;
- BOOST_FOREACH(std::string const& snippet, snippets)
+ out << "[heading Examples]" << std::endl;
+ BOOST_FOREACH(std::string const& example, examples)
{
- out << "[" << snippet << "]" << std::endl;
+ out << "[" << example << "]" << std::endl;
}
out << std::endl;
}
@@ -646,33 +656,12 @@
int arity = (int)f.parameters.size();
std::string additional_description;
-
- if (! f.unique)
- {
- BOOST_FOREACH(param const& p, f.parameters)
- {
- // Boost.Geometry specific, if there is a Strategy parameter,
- // rename the description to " with Strategy"
- // TODO: get this from somewhere
- if (boost::contains(p.type, "Strategy"))
- {
- additional_description = " (with strategy)";
- }
- }
- }
- if (! f.unique && additional_description.empty())
+
+ if (! f.additional_description.empty())
{
- // http://en.wikipedia.org/wiki/Arity
- static std::string const descriptions[] = {"nullary", "unary", "binary", "ternary"
- , "quaternary", "quinary", "senary", "septenary", "octary", "nonary"};
- static int const n = sizeof(descriptions) / sizeof(descriptions[0]);
- if (arity < n)
- {
- std::ostringstream out;
- out << " (" << descriptions[arity] << ")";
- additional_description = out.str();
-
- }
+ additional_description = " (";
+ additional_description += f.additional_description;
+ additional_description += ")";
}
out << "[section:" << f.name;
@@ -749,7 +738,7 @@
out << admonition << std::endl;
}
- quickbook_snippets(f.snippets, out);
+ quickbook_snippets(f.examples, out);
if (! f.images.empty())
{
@@ -783,12 +772,12 @@
}
- if (! f.snippets.empty())
+ if (! f.examples.empty())
{
- out << std::endl << std::endl << "[*Snippets]" << std::endl;
- BOOST_FOREACH(std::string const& snippet, f.snippets)
+ out << std::endl << std::endl << "[*Examples]" << std::endl;
+ BOOST_FOREACH(std::string const& example, f.examples)
{
- out << "[" << snippet << "]" << std::endl;
+ out << "[" << example << "]" << std::endl;
}
}
out << std::endl;
@@ -878,7 +867,7 @@
}
quickbook_header(cos.location, out);
- quickbook_snippets(cos.snippets, out);
+ quickbook_snippets(cos.examples, out);
out << "[endsect]" << std::endl
<< std::endl;
Boost-Commit list run by bdawes at acm.org, david.abrahams at rcn.com, gregod at cs.rpi.edu, cpdaniel at pacbell.net, john at johnmaddock.co.uk
@@ -14,7 +14,7 @@
// - makes use of some specific XML elements, which can be created by Doxygen
// using /xmlonly
-// currently this is the element <qbk.snippet> which will make a reference
+// currently this is the element <qbk.example> which will make a reference
// to an example.
// - earlier generations of QBK was done by XSLT, I'm not so into the XSLT and